@@ -1,5 +1,6 @@
 import yaml
 import json
+import os
 from pathlib import Path
 
 
@@ -113,7 +114,7 @@ def create_docker_compose_file(
     include_flowui_backend: bool = True,
     include_flowui_frontend: bool = False,
     run_scope: str = "deploy-local",
-    repository_config: dict = None
+    flowui_config: dict = None
 ):
     # This needs to run only after ENV vars have been set
     from flowui.scripts.docker_compose_constants import (
